function z = interpol2(X,Y,Z,x,y)

%Interpolation routine based on Z(i,j) = f(X(i),Y(j)).
%Nodes are assumed to be equidistant.

ngridx = length(X);     ngridy = length(Y);
nvalx1 = size(x,1);     nvalx2 = size(x,2);

stepx  = X(2)-X(1);     stepy = Y(2)-Y(1);
minx   = X(1);          miny  = Y(1);

z0  =         0  * ones(size(x,1),size(x,2));
znx = (ngridx-2) * ones(size(x,1),size(x,2));
zny = (ngridy-2) * ones(size(y,1),size(y,2));

jx = min(max(floor((x-minx)/stepx),z0),znx);
jy = min(max(floor((y-miny)/stepy),z0),zny);

fx = (x-jx*stepx-minx)/stepx;
fy = (y-jy*stepy-miny)/stepy;

%Interpolation
z = zeros(nvalx1,nvalx2);
for i = 1:nvalx1
    for j = 1:nvalx2
        jxi = jx(i,j)+1;
        jyi = jy(i,j)+1;
        z(i,j) = (1-fx(i,j)) * (1-fy(i,j)) * Z(jxi  ,jyi  ) ...
               + (1-fx(i,j)) *    fy(i,j)  * Z(jxi  ,jyi+1) ...
               +    fx(i,j)  * (1-fy(i,j)) * Z(jxi+1,jyi  ) ...
               +    fx(i,j)  *    fy(i,j)  * Z(jxi+1,jyi+1);
    end
end